/*
	This file is part of AI Library - Tile
	Copyright (C) 2009-2010  OpenTTD NoAI Community
	
	AI Library - Tile is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public
	License as published by the Free Software Foundation; either
	version 2 of the License, or (at your option) any later version.
	
	AI Library - Tile is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public
	License along with AI Library - Tile; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

require("version.nut");

print("Using AILib.Tile version " + revision);
print("Author          : OpenTTD NoAI Community");
print("License         : GPL version 2.0");
print("Original coder  : Thijs Marinussen (Yexo) && Rifani Arsyad (fanioz)");
print("");

/**
 * AITile extension libraries
 */
class Tile
{
	/**
	 * Check if tile is my tile
	 * @param tile 'tile to check
	 * @return true if "tile" is mine
	 */
	static function IsMyTile(tile)
	{
		return AICompany.IsMine(AITile.GetOwner(tile));
	}

	/**
	 * Check if tile is competitor tile 
	 * @param tile to check
	 * @return true if its owned by competitor
	 */
	static function IsCompetitorTile(tile)
	{
		local owner = AITile.GetOwner(tile);
		return !AICompany.IsMine(owner) && AICompany.COMPANY_INVALID != owner;
	}

	/**
	 * Gets the TileIndex relatively from given offset.
	 * @param tile Start tile.
	 * @param x The X offset.
	 * @param y The Y offset.
	 * @return The new tile.
	 */
	static function AddOffset(tile, x, y)
	{
		if (!AIMap.IsValidTile(tile)) return AIMap.TILE_INVALID;

		local tx = AIMap.GetTileX(tile) + x;
		local ty = AIMap.GetTileY(tile) + y;
		if (tx < 1 || tx > (AIMap.GetMapSizeX() - 2)) return AIMap.TILE_INVALID;
		if (ty < 1 || ty > (AIMap.GetMapSizeY() - 2)) return AIMap.TILE_INVALID;

		return AIMap.GetTileIndex(tx, ty);
	}
}
